@@ -933,7 +933,7 @@ class MatchCapture:
             )
         '''
         if __debug__:
-            def stub(*, capture: "Capture", value: typing.Any) -> None:
+            def stub(*, capture: Capture, value: typing.Any) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
             check_type(argname="argument capture", value=capture, expected_type=type_hints["capture"])
@@ -1007,7 +1007,7 @@ class MatchFailure:
         if __debug__:
             def stub(
                 *,
-                matcher: "Matcher",
+                matcher: Matcher,
                 message: builtins.str,
                 path: typing.Sequence[builtins.str],
             ) -> None:
@@ -1095,7 +1095,7 @@ class MatchResult(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.MatchR
         :param inner: -
         '''
         if __debug__:
-            def stub(id: builtins.str, inner: "MatchResult") -> None:
+            def stub(id: builtins.str, inner: MatchResult) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
@@ -1137,7 +1137,7 @@ class MatchResult(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.MatchR
         '''
         if __debug__:
             def stub(
-                matcher: "Matcher",
+                matcher: Matcher,
                 path: typing.Sequence[builtins.str],
                 message: builtins.str,
             ) -> None:
